import argparse
import iplocalize.localize as ip
from pygments import highlight
from pygments.lexers import PythonLexer
from pygments.formatters import Terminal256Formatter
from pprint import pformat

def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--url", default=ip.default_test_url, type=str,
                        help="URL to test the proxy against (success: http200, within timeout)")
    parser.add_argument("--timeout", default=ip.default_timeout, type=int,
                        help="Timeout")
    parser.add_argument("--threads", default=ip.default_threads, type=int,
                        help="Number of parallel tests we can run")
    parser.add_argument("--geofile", default=ip.geolite_default,
                        help="Path to the Geolite database")
    parser.add_argument("addresses", nargs='+', type=str,
                        help="One or more addresses to tests as free unauthenticated proxies")
    args = parser.parse_args()

    locator = ip.IPLoc(geolite_file=args.geofile,
                       test_url=args.url,
                       timeout=args.timeout,
                       threads=args.threads)
    px_to_check = [ ip_port.split(':') for ip_port in args.addresses ]
    located_px = locator.threaded_localize(px_to_check)
    print(highlight(pformat(located_px), PythonLexer(), Terminal256Formatter()))

if __name__ == '__main__':
    main()



import requests
from multiprocessing.pool import ThreadPool
from geoip2.database import Reader

geolite_default = '/app/GeoLite2-City_20190730/GeoLite2-City.mmdb'
default_test_url = 'https://www.example.com/'
default_threads = 100
default_timeout = 4

class IPLoc(object):
    """
    IPLoc object, an environment to try some (free) proxies and locate them
        - tries to efficiently run with a bunch of threads
        - no non-sense tests
    """
    def __init__(self,
                 geolite_file=geolite_default,
                 test_url=default_test_url,
                 timeout=default_timeout,
                 threads=default_threads,
                ):
        self.test_url = test_url
        self.reader = Reader(geolite_file)
        self.threads = threads
        self.timeout = timeout

    def threaded_localize(self, many_ip):
        """
        Triggers call to localize in a multithreaded fashion
        """
        with ThreadPool(processes=self.threads) as p:
            res = [ p.apply_async(self.localize, (ip,)) for ip in many_ip ]
            return [ r.get() for r in res ]

    def localize(self, ip):
        px = ':'.join(ip)
        proxies = {
            'http': "http://%s" % px,
            'https': "http://%s" % px
        }
        try:
            req = requests.get(self.test_url, proxies=proxies, timeout=self.timeout)
        except requests.exceptions.RequestException:
            return None 
        
        c = self.reader.city(ip_address=ip[0])
        if c is not None and c.country.iso_code is not None and req.status_code == 200:
            return {'ip': px, 'cc': c.country.iso_code, 'time': req.elapsed.total_seconds() }
        else: 
            return None




import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="iplocalize",
    version="0.0.1",
    author="Yoann Lamouroux",
    author_email="ylamouroux@ubuntu.com",
    description="Localize and test a given freeproxy",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/ylmrx/iplocalize",
    packages=setuptools.find_packages(),

    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'requests',
        'geoip2',
        'pygments'
    ],
    entry_points = {
        'console_scripts': ['iplocalize=iplocalize.cmd:main'],
    }
)

